Cite
=====

.. _cite:


If you find ``zoomies`` useful for your work, please cite the ``zoomies`` paper `Sagear et al. 2024 <https://iopscience.iop.org/article/10.3847/1538-4357/ad8b26>`_.

Please also cite the ``gala``, ``agama``, and ``pyia`` Python packages.

